==> zio-aws-route53resolver_2.13-5.17.295.11-sources.jar: zio/aws/route53resolver/model/ResolverAutodefinedReverseStatus.scala <==
package zio.aws.route53resolver.model
import scala.jdk.CollectionConverters._
sealed trait ResolverAutodefinedReverseStatus {
  def unwrap: software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus
}
object ResolverAutodefinedReverseStatus {
  def wrap(
      value: software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus
  ): zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus =
    value match {
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLING =>
        val r = ENABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLED =>
        val r = ENABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLING =>
        val r = DISABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLED =>
        val r = DISABLED
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ENABLING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLING
  }
  case object ENABLED
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLED
  }
  case object DISABLING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLING
  }
  case object DISABLED
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLED
  }
}

==> zio-aws-route53resolver_2.13-7.21.15.8-sources.jar: zio/aws/route53resolver/model/ResolverAutodefinedReverseStatus.scala <==
package zio.aws.route53resolver.model
import scala.jdk.CollectionConverters._
sealed trait ResolverAutodefinedReverseStatus {
  def unwrap: software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus
}
object ResolverAutodefinedReverseStatus {
  def wrap(
      value: software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus
  ): zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus =
    value match {
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLING =>
        val r = ENABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLED =>
        val r = ENABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLING =>
        val r = DISABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLED =>
        val r = DISABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UPDATING_TO_USE_LOCAL_RESOURCE_SETTING =>
        val r = UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.USE_LOCAL_RESOURCE_SETTING =>
        val r = USE_LOCAL_RESOURCE_SETTING
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ENABLING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLING
  }
  case object ENABLED
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.ENABLED
  }
  case object DISABLING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLING
  }
  case object DISABLED
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.DISABLED
  }
  case object UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
  }
  case object USE_LOCAL_RESOURCE_SETTING
      extends zio.aws.route53resolver.model.ResolverAutodefinedReverseStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverAutodefinedReverseStatus.USE_LOCAL_RESOURCE_SETTING
  }
}
